Cancels a job in an Batch job queue. Jobs that are in the SUBMITTED or PENDING are canceled. A job inRUNNABLE remains in RUNNABLE until it reaches the head of the job queue. Then the job status is updated to FAILED.
See https://www.paws-r-sdk.com/docs/batch_cancel_job/ for full documentation.
batch_cancel_job(jobId, reason)[required] The Batch job ID of the job to cancel.
[required] A message to attach to the job that explains the reason for canceling
it. This message is returned by future
describe_jobs operations on the job. This
message is also recorded in the Batch activity logs.