Creates an Amazon EBS-backed AMI from an Amazon EBS-backed instance that is either running or stopped.
See https://www.paws-r-sdk.com/docs/ec2_create_image/ for full documentation.
ec2_create_image(
BlockDeviceMappings = NULL,
Description = NULL,
DryRun = NULL,
InstanceId,
Name,
NoReboot = NULL,
TagSpecifications = NULL
)The block device mappings. This parameter cannot be used to modify the
encryption status of existing volumes or snapshots. To create an AMI
with encrypted snapshots, use the copy_image action.
A description for the new image.
Checks whether you have the required permissions for the action, without
actually making the request, and provides an error response. If you have
the required permissions, the error response is DryRunOperation.
Otherwise, it is UnauthorizedOperation.
[required] The ID of the instance.
[required] A name for the new image.
Constraints: 3-128 alphanumeric characters, parentheses (()), square brackets ([]), spaces ( ), periods (.), slashes (/), dashes (-), single quotes ('), at-signs (@), or underscores(_)
Indicates whether or not the instance should be automatically rebooted before creating the image. Specify one of the following values:
true - The instance is not rebooted before creating the image.
This creates crash-consistent snapshots that include only the data
that has been written to the volumes at the time the snapshots are
created. Buffered data and data in memory that has not yet been
written to the volumes is not included in the snapshots.
false - The instance is rebooted before creating the image. This
ensures that all buffered data and data in memory is written to the
volumes before the snapshots are created.
Default: false
The tags to apply to the AMI and snapshots on creation. You can tag the AMI, the snapshots, or both.
To tag the AMI, the value for ResourceType must be image.
To tag the snapshots that are created of the root volume and of
other Amazon EBS volumes that are attached to the instance, the
value for ResourceType must be snapshot. The same tag is applied
to all of the snapshots that are created.
If you specify other values for ResourceType, the request fails.
To tag an AMI or snapshot after it has been created, see
create_tags.