Deletes a VPC peering connection. Either the owner of the requester VPC
or the owner of the accepter VPC can delete the VPC peering connection
if it's in the active state. The owner of the requester VPC can delete
a VPC peering connection in the pending-acceptance state. You cannot
delete a VPC peering connection that's in the failed state.
ec2_delete_vpc_peering_connection(DryRun, VpcPeeringConnectionId)A list with the following syntax:
list(
Return = TRUE|FALSE
)
Checks whether you have the required permissions for the action, without
actually making the request, and provides an error response. If you have
the required permissions, the error response is DryRunOperation.
Otherwise, it is UnauthorizedOperation.
[required] The ID of the VPC peering connection.
svc$delete_vpc_peering_connection(
DryRun = TRUE|FALSE,
VpcPeeringConnectionId = "string"
)