Learn R Programming

paws.compute (version 0.1.13)

ec2_deregister_instance_event_notification_attributes: Deregisters tag keys to prevent tags that have the specified tag keys from being included in scheduled event notifications for resources in the Region

Description

Deregisters tag keys to prevent tags that have the specified tag keys from being included in scheduled event notifications for resources in the Region.

Usage

ec2_deregister_instance_event_notification_attributes(DryRun,
  InstanceTagAttribute)

Value

A list with the following syntax:

list(
  InstanceTagAttribute = list(
    InstanceTagKeys = list(
      "string"
    ),
    IncludeAllTagsOfInstance = TRUE|FALSE
  )
)

Arguments

DryRun

Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.

InstanceTagAttribute

Information about the tag keys to deregister.

Request syntax

svc$deregister_instance_event_notification_attributes(
  DryRun = TRUE|FALSE,
  InstanceTagAttribute = list(
    IncludeAllTagsOfInstance = TRUE|FALSE,
    InstanceTagKeys = list(
      "string"
    )
  )
)