Describes reservations that are associated with Dedicated Hosts in your account.
ec2_describe_host_reservations(Filter, HostReservationIdSet, MaxResults,
NextToken)A list with the following syntax:
list(
HostReservationSet = list(
list(
Count = 123,
CurrencyCode = "USD",
Duration = 123,
End = as.POSIXct(
"2015-01-01"
),
HostIdSet = list(
"string"
),
HostReservationId = "string",
HourlyPrice = "string",
InstanceFamily = "string",
OfferingId = "string",
PaymentOption = "AllUpfront"|"PartialUpfront"|"NoUpfront",
Start = as.POSIXct(
"2015-01-01"
),
State = "payment-pending"|"payment-failed"|"active"|"retired",
UpfrontPrice = "string",
Tags = list(
list(
Key = "string",
Value = "string"
)
)
)
),
NextToken = "string"
)
The filters.
instance-family - The instance family (for example, m4).
payment-option - The payment option (NoUpfront |
PartialUpfront | AllUpfront).
state - The state of the reservation (payment-pending |
payment-failed | active | retired).
tag:<key> - The key/value combination of a tag assigned to
the resource. Use the tag key in the filter name and the tag value
as the filter value. For example, to find all resources that have a
tag with the key Owner and the value TeamA, specify tag:Owner
for the filter name and TeamA for the filter value.
tag-key - The key of a tag assigned to the resource. Use this
filter to find all resources assigned a tag with a specific key,
regardless of the tag value.
The host reservation IDs.
The maximum number of results to return for the request in a single
page. The remaining results can be seen by sending another request with
the returned nextToken value. This value can be between 5 and 500. If
maxResults is given a larger value than 500, you receive an error.
The token to use to retrieve the next page of results.
svc$describe_host_reservations(
Filter = list(
list(
Name = "string",
Values = list(
"string"
)
)
),
HostReservationIdSet = list(
"string"
),
MaxResults = 123,
NextToken = "string"
)