Registers members (network interfaces) with the transit gateway multicast group. A member is a network interface associated with a supported EC2 instance that receives multicast traffic. For information about supported instances, see Multicast Consideration in Amazon VPC Transit Gateways.
After you add the members, use
search_transit_gateway_multicast_groups
to verify that the members were added to the transit gateway multicast
group.
ec2_register_transit_gateway_multicast_group_members(
TransitGatewayMulticastDomainId, GroupIpAddress, NetworkInterfaceIds,
DryRun)A list with the following syntax:
list(
RegisteredMulticastGroupMembers = list(
TransitGatewayMulticastDomainId = "string",
RegisteredNetworkInterfaceIds = list(
"string"
),
GroupIpAddress = "string"
)
)
The ID of the transit gateway multicast domain.
The IP address assigned to the transit gateway multicast group.
The group members' network interface IDs to register with the transit gateway multicast group.
Checks whether you have the required permissions for the action, without
actually making the request, and provides an error response. If you have
the required permissions, the error response is DryRunOperation.
Otherwise, it is UnauthorizedOperation.
svc$register_transit_gateway_multicast_group_members(
TransitGatewayMulticastDomainId = "string",
GroupIpAddress = "string",
NetworkInterfaceIds = list(
"string"
),
DryRun = TRUE|FALSE
)