Retrieves the results of the lifecycle policy preview request for the specified repository.
ecr_get_lifecycle_policy_preview(registryId, repositoryName, imageIds,
nextToken, maxResults, filter)A list with the following syntax:
list(
registryId = "string",
repositoryName = "string",
lifecyclePolicyText = "string",
status = "IN_PROGRESS"|"COMPLETE"|"EXPIRED"|"FAILED",
nextToken = "string",
previewResults = list(
list(
imageTags = list(
"string"
),
imageDigest = "string",
imagePushedAt = as.POSIXct(
"2015-01-01"
),
action = list(
type = "EXPIRE"
),
appliedRulePriority = 123
)
),
summary = list(
expiringImageTotalCount = 123
)
)
The AWS account ID associated with the registry that contains the repository. If you do not specify a registry, the default registry is assumed.
[required] The name of the repository.
The list of imageIDs to be included.
The nextToken value returned from a previous paginated
GetLifecyclePolicyPreviewRequest request where maxResults was used
and the
results exceeded the value of that parameter. Pagination
continues from the end of the
previous results that returned the
nextToken value. This value is
null when there are no more results
to return. This option cannot be used when you specify images with
imageIds.
The maximum number of repository results returned by
GetLifecyclePolicyPreviewRequest in
paginated output. When this
parameter is used, GetLifecyclePolicyPreviewRequest only returns
maxResults results in a single page along with a nextToken
response
element. The remaining results of the initial request can be seen by
sending
another GetLifecyclePolicyPreviewRequest request with the
returned nextToken
value. This value can be between 1 and 1000. If
this
parameter is not used, then GetLifecyclePolicyPreviewRequest
returns up to
100 results and a nextToken value, if
applicable. This
option cannot be used when you specify images with imageIds.
An optional parameter that filters results based on image tag status and all tags, if tagged.
svc$get_lifecycle_policy_preview(
registryId = "string",
repositoryName = "string",
imageIds = list(
list(
imageDigest = "string",
imageTag = "string"
)
),
nextToken = "string",
maxResults = 123,
filter = list(
tagStatus = "TAGGED"|"UNTAGGED"|"ANY"
)
)