Learn R Programming

paws.compute (version 0.1.0)

ecr_list_tags_for_resource: List the tags for an Amazon ECR resource

Description

List the tags for an Amazon ECR resource.

Usage

ecr_list_tags_for_resource(resourceArn)

Arguments

resourceArn

[required] The Amazon Resource Name (ARN) that identifies the resource for which to list the tags. Currently, the only supported resource is an Amazon ECR repository.

Request syntax

svc$list_tags_for_resource(
  resourceArn = "string"
)