Allows you to change the basic scan type version by setting the name parameter to either CLAIR to AWS_NATIVE.
See https://www.paws-r-sdk.com/docs/ecr_put_account_setting/ for full documentation.
ecr_put_account_setting(name, value)[required] Basic scan type version name.
[required] Setting value that determines what basic scan type is being used:
AWS_NATIVE or CLAIR.