Returns a list of task definition families that are registered to your
account (which may include task definition families that no longer have
any ACTIVE task definition revisions).
You can filter out task definition families that do not contain any
ACTIVE task definition revisions by setting the status parameter to
ACTIVE. You can also filter the results with the familyPrefix
parameter.
ecs_list_task_definition_families(familyPrefix, status, nextToken,
maxResults)A list with the following syntax:
list(
families = list(
"string"
),
nextToken = "string"
)
The familyPrefix is a string that is used to filter the results of
list_task_definition_families. If
you specify a familyPrefix, only task definition family names that
begin with the familyPrefix string are returned.
The task definition family status with which to filter the
list_task_definition_families
results. By default, both ACTIVE and INACTIVE task definition
families are listed. If this parameter is set to ACTIVE, only task
definition families that have an ACTIVE task definition revision are
returned. If this parameter is set to INACTIVE, only task definition
families that do not have any ACTIVE task definition revisions are
returned. If you paginate the resulting output, be sure to keep the
status value constant in each subsequent request.
The nextToken value returned from a
list_task_definition_families
request indicating that more results are available to fulfill the
request and further calls will be needed. If maxResults was provided,
it is possible the number of results to be fewer than maxResults.
This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
The maximum number of task definition family results returned by
list_task_definition_families in
paginated output. When this parameter is used,
list_task_definitions only returns
maxResults results in a single page along with a nextToken response
element. The remaining results of the initial request can be seen by
sending another
list_task_definition_families
request with the returned nextToken value. This value can be between 1
and 100. If this parameter is not used, then
list_task_definition_families
returns up to 100 results and a nextToken value if applicable.
svc$list_task_definition_families(
familyPrefix = "string",
status = "ACTIVE"|"INACTIVE"|"ALL",
nextToken = "string",
maxResults = 123
)
if (FALSE) {
# This example lists all of your registered task definition families.
svc$list_task_definition_families()
# This example lists the task definition revisions that start with "hpcc".
svc$list_task_definition_families(
familyPrefix = "hpcc"
)
}
Run the code above in your browser using DataLab