Modifies an account setting. Account settings are set on a per-Region basis.
See https://www.paws-r-sdk.com/docs/ecs_put_account_setting/ for full documentation.
ecs_put_account_setting(name, value, principalArn = NULL)[required] The Amazon ECS resource name for which to modify the account setting. If
you specify serviceLongArnFormat, the ARN for your Amazon ECS services
is affected. If you specify taskLongArnFormat, the ARN and resource ID
for your Amazon ECS tasks is affected. If you specify
containerInstanceLongArnFormat, the ARN and resource ID for your
Amazon ECS container instances is affected. If you specify
awsvpcTrunking, the elastic network interface (ENI) limit for your
Amazon ECS container instances is affected. If you specify
containerInsights, the default setting for Amazon Web Services
CloudWatch Container Insights for your clusters is affected. If you
specify fargateFIPSMode, Fargate FIPS 140 compliance is affected. If
you specify tagResourceAuthorization, the opt-in option for tagging
resources on creation is affected. For information about the opt-in
timeline, see Tagging authorization timeline
in the Amazon ECS Developer Guide. If you specify
fargateTaskRetirementWaitPeriod, the wait time to retire a Fargate
task is affected.
[required] The account setting value for the specified principal ARN. Accepted
values are enabled, disabled, on, and off.
When you specify fargateTaskRetirementWaitPeriod for the name, the
following are the valid values:
0 - immediately retire the tasks and patch Fargate
There is no advanced notification. Your tasks are retired immediately, and Fargate is patched without any notification.
7 -wait 7 calendar days to retire the tasks and patch Fargate
14 - wait 14 calendar days to retire the tasks and patch Fargate
The ARN of the principal, which can be a user, role, or the root user. If you specify the root user, it modifies the account setting for all users, roles, and the root user of the account unless a user or role explicitly overrides these settings. If this field is omitted, the setting is changed only for the authenticated user.
You must use the root user when you set the Fargate wait time
(fargateTaskRetirementWaitPeriod).
Federated users assume the account setting of the root user and can't have explicit account settings set for them.