Update the list of tags applied to an AWS Elastic Beanstalk resource. Two lists can be passed: TagsToAdd for tags to add or update, and TagsToRemove.
See https://www.paws-r-sdk.com/docs/elasticbeanstalk_update_tags_for_resource/ for full documentation.
elasticbeanstalk_update_tags_for_resource(
ResourceArn,
TagsToAdd = NULL,
TagsToRemove = NULL
)[required] The Amazon Resource Name (ARN) of the resouce to be updated.
Must be the ARN of an Elastic Beanstalk resource.
A list of tags to add or update. If a key of an existing tag is added, the tag's value is updated.
Specify at least one of these parameters: TagsToAdd, TagsToRemove.
A list of tag keys to remove. If a tag key doesn't exist, it is silently ignored.
Specify at least one of these parameters: TagsToAdd, TagsToRemove.