Learn R Programming

paws.compute (version 0.1.13)

lightsail_get_container_images: Returns the container images that are registered to your Amazon Lightsail container service

Description

Returns the container images that are registered to your Amazon Lightsail container service.

If you created a deployment on your Lightsail container service that uses container images from a public registry like Docker Hub, those images are not returned as part of this action. Those images are not registered to your Lightsail container service.

Usage

lightsail_get_container_images(serviceName)

Value

A list with the following syntax:

list(
  containerImages = list(
    list(
      image = "string",
      digest = "string",
      createdAt = as.POSIXct(
        "2015-01-01"
      )
    )
  )
)

Arguments

serviceName

[required] The name of the container service for which to return registered container images.

Request syntax

svc$get_container_images(
  serviceName = "string"
)