Registers sources (network interfaces) with the specified transit gateway multicast group.
A multicast source is a network interface attached to a supported instance that sends multicast traffic. For information about supported instances, see Multicast Considerations in Amazon VPC Transit Gateways.
After you add the source, use
search_transit_gateway_multicast_groups
to verify that the source was added to the multicast group.
ec2_register_transit_gateway_multicast_group_sources(
TransitGatewayMulticastDomainId, GroupIpAddress, NetworkInterfaceIds,
DryRun)A list with the following syntax:
list(
RegisteredMulticastGroupSources = list(
TransitGatewayMulticastDomainId = "string",
RegisteredNetworkInterfaceIds = list(
"string"
),
GroupIpAddress = "string"
)
)
The ID of the transit gateway multicast domain.
The IP address assigned to the transit gateway multicast group.
The group sources' network interface IDs to register with the transit gateway multicast group.
Checks whether you have the required permissions for the action, without
actually making the request, and provides an error response. If you have
the required permissions, the error response is DryRunOperation.
Otherwise, it is UnauthorizedOperation.
svc$register_transit_gateway_multicast_group_sources(
TransitGatewayMulticastDomainId = "string",
GroupIpAddress = "string",
NetworkInterfaceIds = list(
"string"
),
DryRun = TRUE|FALSE
)