Lists the AWS Fargate profiles associated with the specified cluster in your AWS account in the specified Region.
eks_list_fargate_profiles(clusterName, maxResults, nextToken)A list with the following syntax:
list(
fargateProfileNames = list(
"string"
),
nextToken = "string"
)
[required] The name of the Amazon EKS cluster that you would like to listFargate profiles in.
The maximum number of Fargate profile results returned by
list_fargate_profiles in paginated
output. When you use this parameter,
list_fargate_profiles returns only
maxResults results in a single page along with a nextToken response
element. You can see the remaining results of the initial request by
sending another list_fargate_profiles
request with the returned nextToken value. This value can be between 1
and 100. If you don't use this parameter,
list_fargate_profiles returns up to 100
results and a nextToken value if applicable.
The nextToken value returned from a previous paginated
list_fargate_profiles request where
maxResults was used and the results exceeded the value of that
parameter. Pagination continues from the end of the previous results
that returned the nextToken value.
svc$list_fargate_profiles(
clusterName = "string",
maxResults = 123,
nextToken = "string"
)