Update the list of tags applied to an AWS Elastic Beanstalk resource.
Two lists can be passed: TagsToAdd for tags to add or update, and
TagsToRemove.
elasticbeanstalk_update_tags_for_resource(ResourceArn, TagsToAdd,
TagsToRemove)[required] The Amazon Resource Name (ARN) of the resouce to be updated.
Must be the ARN of an Elastic Beanstalk environment.
A list of tags to add or update.
If a key of an existing tag is added, the tag's value is updated.
A list of tag keys to remove.
If a tag key doesn't exist, it is silently ignored.
svc$update_tags_for_resource(
ResourceArn = "string",
TagsToAdd = list(
list(
Key = "string",
Value = "string"
)
),
TagsToRemove = list(
"string"
)
)
Currently, Elastic Beanstalk only supports tagging of Elastic Beanstalk environments. For details about environment tagging, see Tagging Resources in Your Elastic Beanstalk Environment.
If you create a custom IAM user policy to control permission to this operation, specify one of the following two virtual actions (or both) instead of the API operation name:
elasticbeanstalk:AddTags
: Controls permission to call UpdateTagsForResource and pass a list
of tags to add in the TagsToAdd parameter.
elasticbeanstalk:RemoveTags
: Controls permission to call UpdateTagsForResource and pass a list
of tag keys to remove in the TagsToRemove parameter.
For details about creating a custom user policy, see Creating a Custom User Policy.